Inventariseren

# Hydraulic ramp

The hydraulic ramps operate correctly, are inspected and well maintained. Yes No

Explanation: this question relates to all hydraulic ramps present in the company. If you detect that any one of the hydraulic ramps is not in order, you must fill in No. This also applies if your hydraulic ramps number of requirements. The working Conditions Act (Arbowet) makes annual hydraulic ramp maintenance mandatory. You cannot check most requirements yourself and they must be addressed during maintenance. There is, however, a number of Etc. etc.

Please leave any comments you may have on the question above in this field

1. Preparation
2. Inventory
   1. 2.1 Werksoorten
      1. 2.1.1 Handgedragen machinewerk
      2. 2.1.2 Zitgebonden machinewerk zelfrijdende bosbouwmachines
      3. 2.1.3 Hydraulic ramp
         1. Name of step
         2. Name of step
         3. Name of step
         4. Name of step
         5. Name of step
         6. Name of step
         7. Name of step
         8. Name of step
         9. Name of step
         10. Name of step
         11. Name of step
         12. Name of step
         13. Name of step
         14. Name of step
      4. 2.1.4 Onderhoud, werkplaats en opslag.
      5. 2.1.5 Maaiboten
      6. 2.1.6 Surveillance, inventarisatie en rondleidingen
      7. 2.1.7 Werken bij hoogspanningsleidingen
      8. 2.1.8 Kantoorwerk
   2. Bijzondere omstandigheden
3. Evaluation
4. Action plan
5. Reports

Link to sector organisation | Disclaimer | Design by Cornae